<?php
defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'sarahlite_social_media' ) ) {
    /**
     * Get Social Media
     */
    function sarahlite_social_media( $class = 'social-media' ) {
        $show = true;
        $facebook   = get_theme_mod( 'sarahlite_facebook_url' );
        $twitter    = get_theme_mod( 'sarahlite_twitter_url' );
        $instagram  = get_theme_mod( 'sarahlite_instagram_url' );
        $pinterest  = get_theme_mod( 'sarahlite_pinterest_url' );
        $youtube    = get_theme_mod( 'sarahlite_youtube_url' );
        $soundcloud = get_theme_mod( 'sarahlite_soundcloud_url' );
        $vimeo      = get_theme_mod( 'sarahlite_vimeo_url' );
    
        if ( !$facebook && !$twitter && !$instagram && !$pinterest && !$youtube && !$soundcloud && !$vimeo ) {
            $show = false;
        }
    
        if ( $show ) { ?>
        <div class="<?php echo esc_attr( $class ); ?>">
            <?php if( $facebook ) : ?><a href="<?php echo esc_url($facebook); ?>" target="_blank"><i class="fab fa-facebook-f"></i><span><?php echo esc_html__( 'Facebook', 'sarahlite' ); ?></span></a><?php endif; ?>
            <?php if( $twitter ) : ?><a href="<?php echo esc_url($twitter); ?>" target="_blank"><i class="fab fa-twitter"></i><span><?php echo esc_html__( 'Twitter', 'sarahlite' ); ?></span></a><?php endif; ?>
        	<?php if( $instagram ) : ?><a href="<?php echo esc_url($instagram); ?>" target="_blank"><i class="fab fa-instagram"></i><span><?php echo esc_html__( 'Instagram', 'sarahlite' ); ?></span></a><?php endif; ?>
        	<?php if( $pinterest ) : ?><a href="<?php echo esc_url($pinterest); ?>" target="_blank"><i class="fab fa-pinterest-p"></i><span><?php echo esc_html__( 'Pinterest', 'sarahlite' ); ?></span></a><?php endif; ?>
        	<?php if( $youtube ) : ?><a href="<?php echo esc_url($youtube); ?>" target="_blank"><i class="fab fa-youtube"></i><span><?php echo esc_html__( 'Youtube', 'sarahlite' ); ?></span></a><?php endif; ?>
        	<?php if( $soundcloud ) : ?><a href="<?php echo esc_url($soundcloud); ?>" target="_blank"><i class="fab fa-soundcloud"></i><span><?php echo esc_html__( 'Soundcloud', 'sarahlite' ); ?></span></a><?php endif; ?>
        	<?php if( $vimeo ) : ?><a href="<?php echo esc_url($vimeo); ?>" target="_blank"><i class="fab fa-vimeo-square"></i><span><?php echo esc_html__( 'Vimeo', 'sarahlite' ); ?></span></a><?php endif; ?>
        </div>
        <?php
        return $show;
        }
    }
}

if ( ! function_exists( 'sarahlite_custom_comment' ) ) {
    # Comment Layout
    function sarahlite_custom_comment($comment, $args, $depth) {
    	extract($args, EXTR_SKIP);
    
    	if ( 'div' == $args['style'] ) {
    		$tag = 'div';
    		$add_below = 'comment';
    	} else {
    		$tag = 'li';
    		$add_below = 'div-comment';
    	} ?>
    	<<?php echo esc_attr($tag); ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
    	<?php if ( 'div' != $args['style'] ) : ?>
    	<div id="div-comment-<?php comment_ID() ?>" class="comment-body">
    	<?php endif; ?>
    		<div class="comment-author">
    		<?php if ( $args['avatar_size'] != 0 ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
    		</div>
    		<div class="comment-content">
    			<h4 class="author-name"><?php echo get_comment_author_link(); ?></h4>
    			<span class="date-comment">
    				<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
    				<?php printf( __('%1$s at %2$s', 'sarahlite'), get_comment_date(),  get_comment_time() ); ?></a>
    			</span>
    			<div class="reply">
    				<?php edit_comment_link( esc_html__( '(Edit)', 'sarahlite' ), '  ', '' );?>
    				<?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
    			</div>
    			<?php if ( $comment->comment_approved == '0' ) : ?>
    				<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'sarahlite' ); ?></em>
    				<br />
    			<?php endif; ?>
    			<div class="comment-text"><?php comment_text(); ?></div>
    		</div>	
    	<?php if ( 'div' != $args['style'] ) : ?>
    	</div>
    	<?php endif; ?>
    <?php
    }
}

if ( ! function_exists( 'sarahlite_pagination' ) ) {
    # Custom Pagination
    function sarahlite_pagination() {
        if ( get_the_posts_pagination() ) { ?>
        <div class="sarah-pagination"><?php
            $args = array(
                'prev_text' => '<span class="fa fa-angle-left"></span>',
                'next_text' => '<span class="fa fa-angle-right"></span>'
            );
            the_posts_pagination( $args );
        ?>
        </div>
        <?php
        }
    }   
}

if ( ! function_exists( 'sarahlite_core_share' ) ) {
	/**
     * Post sharing
     */
    function sarahlite_core_share() {
        global $post;
        $pin_image = wp_get_attachment_url( get_post_thumbnail_id( $post->ID ) );
        ?>
    	<a target="_blank" href="<?php echo esc_url( 'https://www.facebook.com/sharer/sharer.php?u='. get_the_permalink() ); ?>"><i class="fab fa-facebook"></i></a>
        <a target="_blank" href="<?php echo esc_url( 'https://twitter.com/intent/tweet?text='. get_the_title() . '&url='. get_the_permalink() ); ?>"><i class="fab fa-twitter"></i></a>
        <a target="_blank" href="<?php echo esc_url( 'https://pinterest.com/pin/create/button/?url='. get_the_permalink() . '&media='. esc_url($pin_image) . '&description='. get_the_title() ); ?>"><i class="fab fa-pinterest"></i></a>
        <?php
    }
}

if ( ! function_exists( 'azt_skip_link' ) ) {
	/**
	 * Skip link
	 */
	function azt_skip_link() {
		get_template_part( 'template-parts/site-content/skip-link' );
	}
}

if ( ! function_exists( 'azt_site_branding' ) ) {
	/**
	 * Site branding
	 */
	function azt_site_branding() {
		get_template_part( 'template-parts/site-header/branding' );
	}
}

if ( ! function_exists( 'azt_site_navigation' ) ) {
	/**
	 * Site navigation
	 */
	function azt_site_navigation() {
		get_template_part( 'template-parts/site-header/navigation' );
	}
}

if ( ! function_exists( 'azt_site_content_wrapper_start' ) ) {
	/**
	 * Before start site content
	 */
	function azt_site_content_wrapper_start() {
		get_template_part( 'template-parts/site-content/wrapper-start' );
	}
}

if ( ! function_exists( 'azt_site_content_wrapper_end' ) ) {
	/**
	 * After end site content
	 */
	function azt_site_content_wrapper_end() {
		get_template_part( 'template-parts/site-content/wrapper-end' );
	}
}

if ( ! function_exists( 'azt_featured_posts_slider' ) ) {
	/**
	 * Featured posts slider
	 */
	function azt_featured_posts_slider() {
		get_template_part( 'template-parts/site-content/featured-posts' );
	}
}

if ( ! function_exists( 'azt_promo_boxes' ) ) {
	/**
	 * Promo boxes
	 */
	function azt_promo_boxes() {
		get_template_part( 'template-parts/site-content/promo-boxes' );
	}
}

if ( ! function_exists( 'azt_site_footer_instagram' ) ) {
	/**
	 * Site footer instagram
	 */
	function azt_site_footer_instagram() {
		get_template_part( 'template-parts/site-footer/instagram' );
	}
}

if ( ! function_exists( 'azt_archive_title' ) ) {
	/**
	 * Archive title
	 */
	function azt_archive_title() {
		?>
        <div class="archive-box">
        	<h1 class="archive-title"><?php the_archive_title(); ?></h1>
        </div>
        <?php
	}
}

if ( ! function_exists( 'azt_site_footer_social_icons' ) ) {
	/**
	 * Site footer social icons
	 */
	function azt_site_footer_social_icons() {
		get_template_part( 'template-parts/site-footer/social-icons' );
	}
}

if ( ! function_exists( 'azt_site_footer_copyright' ) ) {
	/**
	 * Site footer social icons
	 */
	function azt_site_footer_copyright() {
		get_template_part( 'template-parts/site-footer/copyright' );
	}
}
